@@ -1,13 +1,13 @@
 import hashlib
 from math import ceil, exp, log, log2
 
-from bitarray.util import zeros
+from bitarray import bitarray
 
 
 class BloomFilter(object):
     """
     Implementation of a Bloom filter.  An instance is initialized by
-    it's capacity `n` and error rate `p`.  The capacity tells how many
+    its capacity `n` and error rate `p`.  The capacity tells how many
     elements can be stored while maintaining no more than `p` false
     positives.
     """
@@ -18,7 +18,7 @@ class BloomFilter(object):
         self.k = ceil(-log2(p))
         # size of array
         self.m = ceil(-n * log2(p) / log(2))
-        self.array = zeros(self.m)
+        self.array = bitarray(self.m)
 
     def calculate_p(self):
         """
@@ -38,6 +38,12 @@ class BloomFilter(object):
             return 0.0
         return -self.m / self.k * log(1 - x / self.m)
 
+    def population(self):
+        """
+        Return the current relative array population as a float.
+        """
+        return self.array.count() / self.m
+
     def add(self, key):
         self.array[list(self._hashes(key))] = 1
 
@@ -52,7 +58,7 @@ class BloomFilter(object):
         n = 1 << self.m.bit_length()
         h = hashlib.new('sha1')
         h.update(str(key).encode())
-        x = int.from_bytes(h.digest(), 'little')
+        x = 0
         i = 0
         while i < self.k:
             if x < n:
@@ -74,17 +80,17 @@ def test_bloom(n, p):
     for i in range(n):
         b.add(i)
         assert i in b
-    print("population: %.2f%%" % (100.0 * b.array.count() / b.m))
+    print("population: %.2f%%" % (100.0 * b.population()))
     print("approx_items(): %.2f" % b.approx_items())
     print("calculate_p(): %.3f%%" % (100.0 * b.calculate_p()))
 
-    N = 100000
+    N = 100_000
     false_pos = sum(i in b for i in range(n, n + N))
     print("experimental : %.3f%%\n" % (100.0 * false_pos / N))
 
 
 if __name__ == '__main__':
-    test_bloom(5000, 0.05)
-    test_bloom(10000, 0.01)
-    test_bloom(50000, 0.005)
-    test_bloom(100000, 0.002)
+    test_bloom(  5_000, 0.05)
+    test_bloom( 10_000, 0.01)
+    test_bloom( 50_000, 0.005)
+    test_bloom(100_000, 0.002)
